==> crypt-core-4.13.0-sources.jar: de/alpharogroup/crypto/factories/AlgorithmParameterSpecFactory.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.crypto.factories;

import java.security.spec.AlgorithmParameterSpec;

import javax.crypto.spec.PBEParameterSpec;

/**
 * A factory for creating AlgorithmParameterSpec objects.
 */
public class AlgorithmParameterSpecFactory
{

	/**
	 * Factory method for creating a new {@link PBEParameterSpec} from the given salt and iteration count.
	 *
	 * @param salt the salt
	 * @param iterationCount the iteration count
	 * @return the new {@link PBEParameterSpec} from the given salt and iteration count.
	 */
	public static AlgorithmParameterSpec newPBEParameterSpec(final byte[] salt,final int iterationCount){
		final AlgorithmParameterSpec paramSpec = new PBEParameterSpec(salt, iterationCount);
		return paramSpec;
	}
}

==> crypt-core-4.15.0-sources.jar: de/alpharogroup/crypto/factories/AlgorithmParameterSpecFactory.java <==
/**
 * The MIT License
 *
 * Copyright (C) 2015 Asterios Raptis
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package de.alpharogroup.crypto.factories;

import java.security.spec.AlgorithmParameterSpec;

import javax.crypto.spec.PBEParameterSpec;

import lombok.experimental.UtilityClass;

/**
 * A factory for creating {@link AlgorithmParameterSpec} objects.
 */
@UtilityClass
public class AlgorithmParameterSpecFactory
{

	/**
	 * Factory method for creating a new {@link PBEParameterSpec} from the given salt and iteration
	 * count.
	 *
	 * @param salt
	 *            the salt
	 * @param iterationCount
	 *            the iteration count
	 * @return the new {@link PBEParameterSpec} from the given salt and iteration count.
	 */
	public static AlgorithmParameterSpec newPBEParameterSpec(final byte[] salt,
		final int iterationCount)
	{
		final AlgorithmParameterSpec paramSpec = new PBEParameterSpec(salt, iterationCount);
		return paramSpec;
	}
}
